@@ -2,7 +2,7 @@ package Squatting::On::Continuity;
 
 use strict;
 no  strict 'refs';
-use warnings;
+#use warnings;
 use Continuity;
 use Squatting::Mapper;
 
@@ -91,7 +91,7 @@ sub continue {
         my $content  = $app->service($cc, @$p);
         my $response = HTTP::Response->new(
           $cc->status,
-          HTTP::Status::status_message($cc->status),
+          undef,
           [%{$cc->{headers}}],
           $content
         );
@@ -135,16 +135,12 @@ L<Continuity> has 2 highly unusual (but useful) capabilities.
 
 =item 1. It can hold many simultaneous HTTP connections open.
 
-Each session is allocated its own L<Coro>-based coroutine.  Under Squatting,
-you can also specify controller-method pairs that should execute under their
-own coroutine.  Thus, each session may run 1 or more coroutines.
-
 =item 2. It can "pause" execution until the next request comes in.
 
-The easiest way to explain this is by example.
-
 =back
 
+The easiest way to explain this is by example.
+
 =head2 Becoming RESTless
 
 Consider this controller which has an infinite loop in it.
@@ -160,7 +156,7 @@ Consider this controller which has an infinite loop in it.
         $cr->next;
       }
     },
-    queue => { get => 'arbitrary_string' }
+    queue => { get => 'name_of_queue' }
   )
 
 Here, the code is dropping down to the Continuity level.  The C<$cr> variable
@@ -187,7 +183,7 @@ have to come in.
 
 The key is this line:
 
-  queue => { get => 'arbitrary_string' }
+  queue => { get => 'name_of_queue' }
 
 When you're squatting on Continuity, you're allowed to define your controllers
 with a C<queue> attribute.  It should contain a hashref where the keys are HTTP
